@@ -24,7 +24,7 @@
 
 #include "gkd-secret-types.h"
 
-#include "gck/gck.h"
+#include <gck/gck.h>
 
 #include <dbus/dbus.h>
 
@@ -79,4 +79,10 @@ void                    gkd_secret_service_publish_dispatch        (GkdSecretSer
                                                                     const gchar *caller,
                                                                     GkdSecretDispatch *object);
 
+void                    gkd_secret_service_emit_collection_created (GkdSecretService *self,
+                                                                    const gchar *collection_path);
+
+void                    gkd_secret_service_emit_collection_deleted (GkdSecretService *self,
+                                                                    const gchar *collection_path);
+
 #endif /* ___SECRET_SERVICE_H__ */
