@@ -61,7 +61,9 @@ main(int argc, char* argv[])
 	GkmSecret *login;
 	int fd;
 
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 	gkm_crypto_initialize ();
 
 	if (argc != 2)
